==> otf_api-0.9.4-py3-none-any.whl: otf_api/models/__init__.py <==
from .body_composition_list import BodyCompositionData
from .bookings import Booking
from .challenge_tracker_content import ChallengeTracker
from .challenge_tracker_detail import FitnessBenchmark
from .classes import OtfClass
from .enums import BookingStatus, ChallengeCategory, ClassType, DoW, EquipmentType, StatsTime, StudioStatus
from .lifetime_stats import StatsResponse, TimeStats
from .member_detail import MemberDetail
from .member_membership import MemberMembership
from .member_purchases import MemberPurchase
from .notifications import EmailNotificationSettings, SmsNotificationSettings
from .out_of_studio_workout_history import OutOfStudioWorkoutHistory
from .performance_summary_detail import PerformanceSummaryDetail
from .performance_summary_list import PerformanceSummaryEntry
from .studio_detail import StudioDetail
from .studio_services import StudioService
from .telemetry import Telemetry, TelemetryHistoryItem

__all__ = [
    "BodyCompositionData",
    "Booking",
    "BookingStatus",
    "ChallengeCategory",
    "ChallengeParticipation",
    "ChallengeTracker",
    "ClassType",
    "DoW",
    "EmailNotificationSettings",
    "EquipmentType",
    "FitnessBenchmark",
    "LatestAgreement",
    "MemberDetail",
    "MemberMembership",
    "MemberPurchase",
    "OtfClass",
    "OutOfStudioWorkoutHistory",
    "PerformanceSummaryDetail",
    "PerformanceSummaryEntry",
    "SmsNotificationSettings",
    "StatsResponse",
    "StatsTime",
    "StudioDetail",
    "StudioService",
    "StudioStatus",
    "Telemetry",
    "TelemetryHistoryItem",
    "TimeStats",
]

==> otf_api-0.11.0rc1-py3-none-any.whl: otf_api/models/__init__.py <==
from .body_composition_list import BodyCompositionData
from .bookings import Booking
from .bookings_v2 import BookingV2, BookingV2Class
from .challenge_tracker_content import ChallengeTracker
from .challenge_tracker_detail import FitnessBenchmark
from .classes import OtfClass
from .enums import (
    HISTORICAL_BOOKING_STATUSES,
    BookingStatus,
    ChallengeCategory,
    ClassType,
    DoW,
    EquipmentType,
    StatsTime,
    StudioStatus,
)
from .lifetime_stats import InStudioStatsData, OutStudioStatsData, StatsResponse, TimeStats
from .member_detail import MemberDetail
from .member_membership import MemberMembership
from .member_purchases import MemberPurchase
from .notifications import EmailNotificationSettings, SmsNotificationSettings
from .out_of_studio_workout_history import OutOfStudioWorkoutHistory
from .performance_summary import PerformanceSummary
from .ratings import get_class_rating_value, get_coach_rating_value
from .studio_detail import StudioDetail
from .studio_services import StudioService
from .telemetry import Telemetry, TelemetryHistoryItem
from .workout import Workout

__all__ = [
    "HISTORICAL_BOOKING_STATUSES",
    "BodyCompositionData",
    "Booking",
    "BookingStatus",
    "BookingV2",
    "BookingV2Class",
    "ChallengeCategory",
    "ChallengeTracker",
    "ClassType",
    "DoW",
    "EmailNotificationSettings",
    "EquipmentType",
    "FitnessBenchmark",
    "InStudioStatsData",
    "MemberDetail",
    "MemberMembership",
    "MemberPurchase",
    "OtfClass",
    "OutOfStudioWorkoutHistory",
    "OutStudioStatsData",
    "PerformanceSummary",
    "SmsNotificationSettings",
    "StatsResponse",
    "StatsTime",
    "StudioDetail",
    "StudioService",
    "StudioStatus",
    "Telemetry",
    "TelemetryHistoryItem",
    "TimeStats",
    "Workout",
    "get_class_rating_value",
    "get_coach_rating_value",
]
